##----------------------------------------------------------------------------##
##=Purpose: Exercise 2.1 of Beyond Classic Designs & Analysis for Health      ##
##          Data in Singapore (27 June to 8 July 2022)                        ##
##
##=Data required: 
##  - 2.1_framingham_exercises.dta
##
##=R packages/libraries required:
##  - car:
##    * Anova: Get the Anova table
##  - epiDisplay: 
##    * mhor: Provides Mantel-Haenszel OR and the subgroups ORs
##    Note: - mantelhaen.test function generates Mantel-Haenszel OR
##          - EpiStats library has CCInter provides detailed information, such,
##            Mantel-Haenszel OR and the subgroups ORs, and crude OR too.
##          - epiR library has epi.2by2 provides crude and Mantel-Haenszel 
##            adjusted measures of association and chi-squared tests of 
##            homogeneity
##  - haven:
##    * read_dta: To read in recent versions of STATA dta files.
##  - MASS:
##    * confint.default: generate 95% using wald approach  
##
##=Created by:
##  - Francesca Graziano 
##  - Zilu Feng
##  - Zihan 
##  - Chuen Seng Tan
##  - Marie Reilly
##
##=Changes (if any):
##  -07062022: Updated Question 1 (iii) and (iv) & Q2(i)
##
##  -DDMMYYYY: Describe
##
##----------------------------------------------------------------------------##

##-Set the working directory to the data folder where the datasets are saved:
setwd("D:/nbox/Education/Marie_short_course/Singapore course 2022/20220602/exercises/data")

##-R libraries to install:
#install.packages(c("car","epiDisplay","haven","MASS"))
##-Load the R libraries
library(car)
library(epiDisplay)
library(haven)
library(MASS)


################################################################################
## These exercises are based on the dataset set "2.1_Framingham_exercises.dta", 
## which contains the individual records for the participants in the Framingham 
## study who were summarised in the tables in Exercise 1.2. The data set 
## includes the following variables:
##  
## * sex (1=male, 2=female)
## * age (age, in years)
## * agecat (four age categories in 10-year intervals: 0=32-41, 1=42-51, 2=52-61, 3=62-71)
## * diabetes (treatment or glucose >=200mg/dL:  0=no diabetes, 1=diabetes)
## * anychd (0=any CHD during follow-up, 1=no CHD during follow-up) 
## * prevchd (0=no prevalent coronary heart disease, CHD, 1=prevalent CHD)
## * prevhyp (0=no prevalent hypertension, 1=prevalent hypertension)
################################################################################


################################################################################
##                               Question 1 (i)      
##
##-1.(i)	For individuals aged 42 and older (i.e. agecat=1,2,3), reproduce the 
##        following counts for incident CHD (anychd) and diabetes (already used 
##        in Exercise 1.2)
##
##        [see exercise for the table]
##
################################################################################

#1- import dataset
data<- read_dta("2.1_framingham_exercises.dta")
data42<-data[data$age>=42,]

M1<-table(data42$prevchd, data42$diabetes, data42$agecat)
M1


################################################################################
##                               Question 1 (ii)      
##
##-1.(ii)	Run a logistic regression to obtain the crude OR and check it against 
##        your answer from Exercise 1.2. 
################################################################################

#1- fit the model
model1 <- glm(diabetes~prevchd , family=binomial("logit"), data=data42)
summary(model1)

#2 - extract	OR and 95%CI from the model
OR<-round(exp(model1$coefficients),3)
CI<-round(exp(confint.default(model1)),3)
cbind(OR,CI)


################################################################################
##                               Question 1 (iii)      
##
##- 1. (iii)	Estimate the adjusted OR and compare to your answer in Exercise 1.2. 
################################################################################

#1 - fit the model
model2 <- glm(diabetes~prevchd+ as.factor(agecat) , family=binomial("logit"), data=data42)
summary(model2)

#2 - extract the	OR and 95%CIfrom the model
OR<-round(exp(model2$coefficients),3)
CI<-round(exp(confint.default(model2)),3)
cbind(OR,CI)


################################################################################
##                               Question 1 (iv)      
##
##-1. (iv)	Add an interaction term to your model in (iii) and compare the 
##          results to your conclusion regarding heterogeneity in Exercise 1.2 
################################################################################

#1 - fit the model
model3 <- glm(diabetes~prevchd*as.factor(agecat), family=binomial("logit"), data=data42)
summary(model3)

#2 - extract the	OR and 95%CI from the model
OR<-round(exp(model3$coefficients),3)
CI<-round(exp(confint.default(model3)),3)
cbind(OR,CI)

#3- p-value for interaction
car::Anova(model3,test="Wald")
      

################################################################################
##                               Question 2     
##
##-2. The following exercise compares the 2-by-2 tables analysis with logistic 
##    regression
################################################################################

################################################################################
##                               Question 2 (i)      
##
##-(i) Reproduce the following tables describing the association between 
##     prevalent hypertension (prevhyp) and diabetes for the 3505 individuals 
##     aged 42 or older: 
##
##     [see exercise for the table]
##
################################################################################

#1- crude OR
M1<-table(data42$prevhyp,data42$diabetes) 
M1

fisher.test(M1)

#2-Compute the OR (with 95% CI) by age group and MH-OR
M1<-table(data42$prevhyp,data42$diabetes,data42$sex) 
M1

#3- OR by age group and MH-OR
epiDisplay::mhor(mhtable=M1, graph = F)


################################################################################
##                               Question 2 (ii)      
##
##- (ii) Analyse the data using a logistic regression model with interaction 
##       term to reproduce the following example in the draft text book (Note 
##       that the confidence intervals may differ slightly depending on the 
##       software and command/package that you use):
##
##       [see exercise for the table]
##
################################################################################

#1- unadjusted model
model0 <- glm(diabetes~prevhyp , family=binomial("logit"), data=data42)
summary(model0)

#2- extract	OR and 95%CI from the model
OR<-round(exp(model0$coefficients[]),3)
CI<-round(exp(confint.default(model0)),3)
cbind(OR,CI)

#3- model with interaction term:
model3 <- glm(diabetes~prevhyp*sex , family=binomial("logit"), data=data42)
summary(model3)

#4- extract OR and 95%CI from the model
OR<-round(exp(model3$coefficients[]),3)
CI<-round(exp(confint.default(model3)),3)
cbind(OR,CI)


################################################################################
##                               Question 2 (iii)      
##
##-(iii) How can the OR for females found in (i) be obtained from the output 
##       in (ii)? 
################################################################################

#1- calculate the effect of the exposure in Female:
exp(log(1.429)+ log(2.896))

#2- calculate the effect of the exposure in Male
exp(log(1.429))

################################################################################
##                               Question 3 (i)      
##
##  3.	(optional)
##-(i)	Run a logistic regression analysis of diabetes in the cohort aged 40 
##      and above and record the crude OR for the effect of prevalent CHD 
##      (variable name prevchd) on diabetes (variable name diabetes), also the 
##      ln(OR) and the intercept of the logistic model.
################################################################################

#1- import dataset
data<- read_dta("2.1_framingham_exercises.dta")
data40<-data[data$age>=40,]

#2- fit the model
model1 <- glm(diabetes~prevchd , family=binomial("logit"), data=data40)
summary(model1)

#3- extract OR and 95%CI from the model
OR<-round(exp(model1$coefficients[]),3)
OR.CI<-round(exp(confint.default(model1)),3)
cbind(OR,OR.CI)

#4 - extract log-OR and intercept from the model
LOR<-round(model1$coefficients[],3)
LOR.CI<-round(confint.default(model1),3)
cbind(LOR,LOR.CI)


################################################################################
##                               Question 3 (ii)      
##
##- (ii)	Select a case-control sample consisting of all cases and an equal 
##        number of controls (chosen randomly: use a "seed" so that you can 
##        reproduce your results if needed).
################################################################################

#Cases and controls into 2 separate dataframes
data40.case <- data40[which(data40$diabetes==1),]
data40.cont.all <- data40[which(data40$diabetes==0),]

#The number of cases
nrow(data40.case)
#The number of controls
nrow(data40.cont.all)

#set seed so the same set of random numbers will be generated all the time
set.seed(2307)
#select 116 random rows and send them to the new dataframe 
id<-sample(1:nrow(data40.cont.all),nrow(data40.case))  

#combine case and controls into a single dataset
data40.cc <- rbind(data40.case, 
                   data40.cont.all[id,])


################################################################################
##                               Question 3 (ii)      
##
##-(iii)	Re-run the logistic regression using the case-control sample, again 
##        recording the crude OR for the effect of prevalent CHD, also the 
##        ln(OR) and the intercept. Compare to your estimate in (i): the OR or 
##        ln(OR) should agree to within sampling variation, but the intercept 
##        will be very different.
################################################################################

#1- fit the model
model1.cc <- glm(diabetes~prevchd , family=binomial("logit"), data=data40.cc)
summary(model1.cc)

#2 - extract OR and 95%CI from the model
OR<-round(exp(model1.cc$coefficients[]),3)
OR.CI<-round(exp(confint.default(model1.cc)),3)
cbind(OR,OR.CI)

#3 - extract log-OR and intercept from the model
LOR<-round(model1.cc$coefficients[],3)
LOR.CI<-round(confint.default(model1.cc),3)
cbind(LOR,LOR.CI)
