//----------------------------------------------------------------------------//
//=Purpose: Exercise 2.1 of Beyond Classic Designs & Analysis for Health      //
//          Data in Singapore (27 June to 8 July 2022)                        //
//
//=Data required: 
//  - 2.1_framingham_exercises.dta
//
//=Stata packages/libraries required:
//  - None
//
//=Created by:
//  - Zihan 
//  - Francesca Graziano 
//  - Zilu Feng
//  - Chuen Seng Tan
//  - Marie Reilly
//
//=Changes (if any):
//  -07062022: Updated Question 1 (iii) and (iv) & Q2(i)
//
// Last Run: 8 June 20022 (Marie)

//----------------------------------------------------------------------------//

//-Set the working directory to the data folder where the datasets are saved:
// "D:/nbox/Education/Marie_short_course/Singapore course 2022/20220602/exercises/data"

cd "Z:\teaching\active\courses\Singapore 2022\Exercises\Session 2"



////////////////////////////////////////////////////////////////////////////////
// These exercises are based on the dataset set "2.1_Framingham_exercises.dta", 
// which contains the individual records for the participants in the Framingham 
// study who were summarised in the tables in Exercise 1.2. The data set 
// includes the following variables:
//  
// * sex (1=male, 2=female)
// * age (age, in years)
// * agecat (four age categories in 10-year intervals: 0=32-41, 1=42-51, 2=52-61, 3=62-71)
// * diabetes (treatment or glucose >=200mg/dL:  0=no diabetes, 1=diabetes)
// * anychd (0=any CHD during follow-up, 1=no CHD during follow-up) 
// * prevchd (0=no prevalent coronary heart disease, CHD, 1=prevalent CHD)
// * prevhyp (0=no prevalent hypertension, 1=prevalent hypertension)
////////////////////////////////////////////////////////////////////////////////


////////////////////////////////////////////////////////////////////////////////
//                               Question 1 (i)      
//
//-1.(i) For individuals aged 42 and older (i.e. agecat=1,2,3), reproduce the 
//       following counts for incident CHD (anychd) and diabetes (already used 
//       in Exercise 1.2)
//
//       [see exercise for the table]
//
////////////////////////////////////////////////////////////////////////////////

*Load dataset and drop people aged<42:
use "2.1_framingham_exercises.dta", clear
drop if agecat==0

*Reproduce counts:
tab prevchd diabetes if agecat==1
tab prevchd diabetes if agecat==2
tab prevchd diabetes if agecat==3


////////////////////////////////////////////////////////////////////////////////
//                               Question 1 (ii)      
//
//-1.(ii) Run a logistic regression to obtain the crude OR and check it against 
//        your answer from Exercise 1.2. 
////////////////////////////////////////////////////////////////////////////////

logit diabetes prevchd, or


////////////////////////////////////////////////////////////////////////////////
//                               Question 1 (iii)      
//
//- 1. (iii) Estimate the adjusted OR and compare to your answer in Exercise 1.2. 
////////////////////////////////////////////////////////////////////////////////

logit diabetes prevchd i.agecat, or


////////////////////////////////////////////////////////////////////////////////
//                               Question 1 (iv)      
//
//-1. (iv) Add an interaction term to your model in (iii) and compare the 
//         results to your conclusion regarding heterogeneity in Exercise 1.2 
////////////////////////////////////////////////////////////////////////////////

logit diabetes prevchd##i.agecat, or

*test interaction:
testparm prevchd#i.agecat

////////////////////////////////////////////////////////////////////////////////
//                               Question 2     
//
//-2. The following exercise compares the 2-by-2 tables analysis with logistic 
//    regression
////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////
//                               Question 2 (i)      
//
//-(i) Reproduce the following tables describing the association between 
//     prevalent hypertension (prevhyp) and diabetes for the 3505 individuals 
//     aged 42 or older: 
//
//     [see exercise for the table]
//
////////////////////////////////////////////////////////////////////////////////

*Crude OR:
cc diabetes prevhyp 

*ORs stratified by sex:
cc diabetes prevhyp, by(sex)


////////////////////////////////////////////////////////////////////////////////
//                               Question 2 (ii)      
//
//- (ii) Analyse the data using a logistic regression model with interaction 
//       term to reproduce the following example in the draft text book (Note 
//       that the confidence intervals may differ slightly depending on the 
//       software and command/package that you use):
//
//       [see exercise for the table]
//
////////////////////////////////////////////////////////////////////////////////

*unadjusted logistic model:
logit diabetes prevhyp, or

*generate interaction term:
* since both are indicator variables, can use product
gen inter=prevhyp*sex

*include interaction term in logistic regression model: 
logit diabetes prevhyp sex inter, or


////////////////////////////////////////////////////////////////////////////////
//                               Question 2 (iii)      
//
//-(iii) How can the OR for females found in (i) be obtained from the output 
//       in (ii)? 
////////////////////////////////////////////////////////////////////////////////



////////////////////////////////////////////////////////////////////////////////
//                               Question 3 (i)      
//
//  3.	(optional)
//-(i)	Run a logistic regression analysis of diabetes in the cohort aged 40 
//      and above and record the crude OR for the effect of prevalent CHD 
//      (variable name prevchd) on diabetes (variable name diabetes), also the 
//      ln(OR) and the intercept of the logistic model.
////////////////////////////////////////////////////////////////////////////////

*Load dataset and drop people aged<40:
clear all
use 2.1_Framingham_exercises.dta
drop if age<40

*compute intercept and ln(OR):
logit diabetes prevchd

*compute crude OR:
logistic diabetes prevchd

*This gives crude OR=2.26, ln(OR)=0.82, and intercept=-3.52


////////////////////////////////////////////////////////////////////////////////
//                               Question 3 (ii)      
//
//- (ii)	Select a case-control sample consisting of all cases and an equal 
//        number of controls (chosen randomly: use a "seed" so that you can 
//        reproduce your results if needed).
////////////////////////////////////////////////////////////////////////////////


tab diabetes
*There are 118 diabetes cases:
*So select 118 non-cases (using random number & seed) and append with cases:

preserve
keep if diabetes == 0
set seed 1810
sample 118, count
tempfile controls
save `controls'
restore
keep if diabetes == 1
append using `controls'


////////////////////////////////////////////////////////////////////////////////
//                               Question 3 (iii)      
//
//-(iii)	Re-run the logistic regression using the case-control sample, again 
//        recording the crude OR for the effect of prevalent CHD, also the 
//        ln(OR) and the intercept. Compare to your estimate in (i): the OR or 
//        ln(OR) should agree to within sampling variation, but the intercept 
//        will be very different.
////////////////////////////////////////////////////////////////////////////////

logit diabetes prevchd
logistic diabetes prevchd
